"""
Convert numbers into their Dutch written form.
"""

from .telwoord import cardinal, ordinal
